<?php
get_header();

$today = date('Ymd'); // Today's date
?>

<section class="upcoming-webinars bg-gray">
  <div class="container py-2x">
    <div class="row justify-content-center mb-2x">
      <div class="col col-md-8 text-center">
        <h1 class="mb-1x">Webinars</h1>
        <h3>Upcoming Live Webinars</h3>
      </div>
    </div>
    <div class="row justify-content-center">
    <?php
      // Set new query for CPT of webinars ordered by date
      $webinars = new WP_Query(
        array(
          'post_type' => 'webinars',
          'posts_per_page' => -1,
          'meta_key'  => 'webinar_date',
          'orderby' => 'meta_value_num',
          'order'   => 'ASC',
          'meta_query' => array(
            array(
              'key'   => 'webinar_date',
              'compare' => '>=',
              'value'   => $today,
            )
          )
        )
      );
      // Get webinars that are before Today's date
      if ( $webinars->have_posts() ) : while ( $webinars->have_posts() ) : $webinars->the_post();
      $webinar = get_field('webinar_date'); // Webinar Date
      $formatDate = date('F d', strtotime($webinar)); // Format Webinar date to Month, day
    ?>

      <div class="col-12 col-md-6 col-lg-3 mb-2x card-group">
        <div class="card justify-content-center align-items-center">
          <img src="<?php echo get_stylesheet_directory_uri()?>/assets/img/icons/icn-webinars.svg"/>
          <p class="my-1x text-center"><?php the_title();?></p>
          <p class="sm"><?php echo $formatDate;?> @ <?php the_field('webinar_time');?> (PT)</p>
          <a href="<?php the_permalink();?>" class="btn btn-outline-success btn-block --green">Join this Webinar</a>
        </div>
      </div>

      <?php endwhile; else: // show message if nothing upcomming ?>

    </div>

    <div class="row justify-content-center">
      <div class="col text-center">
        <p>Sorry, there are no upcoming webinars at this time. Checkout some of our previous webinars below.</p>
      </div>

    <?php endif; ?>

    </div>
  </div>
</section>

<section class="past-webinars bb py-4x">
  <div class="container">
    <div class="row mb-2x">
      <div class="col text-center">
        <h4>Past Webinars</h4>
      </div>
    </div>
    <div class="row justify-content-center">
      <?php
        // Set new query for CPT of webinars
        $webinars = new WP_Query(
          array(
            'post_type' => 'webinars',
            'orderby' => 'menu_order',
            'posts_per_page' => -1,
          )
        );
        // Get Webinars that are after today's date
        if ( $webinars->have_posts() ) : while ( $webinars->have_posts() ) : $webinars->the_post();
        $webinar = get_field('webinar_date'); // Webinar Date
        $formatDate = date('F d', strtotime($webinar)); // Format Webinar date to Month, day
        if ($today > $webinar) {
      ?>

      <div class="col-12 col-md-6 col-lg-3 mb-2x card-group">
        <div class="card text-center justify-content-center align-items-center">
          <img src="<?php echo get_stylesheet_directory_uri()?>/assets/img/icons/icn-webinars.svg"/>
          <p class="my-1x"><?php the_title();?></p>
          <?php if (get_field('webinar_recording_url')) { ?>
          <a href="<?php the_permalink();?>" class="btn btn-outline-success btn-block --green mt-2x">Watch now</a>
          <?php } else {?>
            <a href="<?php the_field('webinar_recording_url');?>" class="disabled btn btn-outline-success btn-block --green mt-2x">Watch Soon</a>
          <?php }?>
        </div>
      </div>

      <?php } endwhile; endif; ?>
    </div>
  </div>
</section>

<?php get_footer(); ?>
