<?php
/*===================================================================================
* Add global options
* =================================================================================*/

/**
 *
 * The page content surrounding the settings fields. Usually you use this to instruct non-techy people what to do.
 *
 */
function theme_settings_page(){ ?>
	<div class="wrap">
		<h1>Kong Current Version</h1>
		<p>Use the field below to define what version should be displayed on the site front end.</p>
		<form method="post" action="options.php">
			<?php
			settings_fields("section");
			do_settings_sections("kong-version-options");
			submit_button();
			?>
		</form>
	</div>
<?php }


function pardot_settings_page(){ ?>
	<div class="wrap">
		<h1>Set Global Pardot User</h1>
		<p>Use the fields below to define what Pardot user should be used to submit forms.</p>
		<form method="post" action="options.php">
			<?php
			settings_fields("pardot-options");
			do_settings_sections("pardot_options");
			submit_button();
			?>
		</form>
	</div>
	<div class="wrap">
		<h1>Set Global Zendesk User</h1>
		<p>Use the fields below to define what Zendesk user should be used to create Free Trial users in Zendesk.</p>
		<form method="post" action="options.php">
			<?php
			settings_fields("zendesk-options");
			do_settings_sections("zendesk_options");
			submit_button();
			?>
		</form>
	</div>
	<div class="wrap">
		<h1>Set Bintray Access Key</h1>
		<p>Use the field below to define what Bintray user should be used to create Free Trial signed URLS from Bintray and Bintray Repo URLS</p>
		<form method="post" action="options.php">
			<?php
			settings_fields("bintray-options");
			do_settings_sections("bintray_options");
			submit_button();
			?>
		</form>
	</div>
	<div class="wrap">
		<h1>Set License API Credentials</h1>
		<p>Used to create licenses for Free Trials customers</p>
		<form method="post" action="options.php">
			<?php
			settings_fields("licenseAPI-options");
			do_settings_sections("licenseAPI_options");
      submit_button();
      ?>
    </form>
  </div>
  <div class="wrap">
		<h1>Set Clearbit Risk API Key</h1>
		<p>Use the field below to define what Clearbit apikey should be used for the Risk API.</p>
		<form method="post" action="options.php">
			<?php
			settings_fields("clearbit-options");
			do_settings_sections("clearbit_options");
			submit_button();
			?>
		</form>
	</div>
	<div class="wrap">
		<h1>Set Salesforce API Auth</h1>
		<p>Use the fields below to set the Salesforce API user and password.</p>
		<form method="post" action="options.php">
			<?php
			settings_fields("salesforce-options");
			do_settings_sections("salesforce_options");
			submit_button();
			?>
		</form>
	</div>
<?php }

/**
 *
 * Next comes the settings fields to display. Use anything from inputs and textareas, to checkboxes multi-selects.
 *
 */

// Kong Version
function display_kong_version_element(){ ?>

	<input type="text" name="kong_version" placeholder="Enter Kong Version" value="<?php echo get_option('kong_version'); ?>" size="10">

<?php }

// Pardot
function display_pardot_element(){ ?>

	<input type="text" name="pardot_email" placeholder="Enter Pardot User Email" value="<?php echo get_option('pardot_email'); ?>" >
	<input type="text" name="pardot_pass" placeholder="Enter Pardot User Password" value="<?php echo get_option('pardot_pass'); ?>" >
	<input type="text" name="pardot_key" placeholder="Enter Pardot User Key" value="<?php echo get_option('pardot_key'); ?>" >

<?php }

function display_zendesk_element(){ ?>

	<input type="text" name="zendesk_email" placeholder="Enter Zendesk User Email with access token" value="<?php echo get_option('zendesk_email'); ?>" >

<?php }

function display_bintray_element(){ ?>

	<input type="text" name="bintray_key" placeholder="Access Key" value="<?php echo get_option('bintray_key'); ?>" >
	<input type="text" name="bintray_robot_key" placeholder="Robot Key" value="<?php echo get_option('bintray_robot_key'); ?>" >
	<input type="text" name="bintray_docker" placeholder="Enter Docker Bintray URL" value="<?php echo get_option('bintray_docker'); ?>" >
	<input type="text" name="bintray_aws" placeholder="Enter AWS Bintray URL" value="<?php echo get_option('bintray_aws'); ?>" >
	<input type="text" name="bintray_centos" placeholder="Enter CentOS Bintray URL" value="<?php echo get_option('bintray_centos'); ?>" >
	<input type="text" name="bintray_debian" placeholder="Enter Debian Bintray URL" value="<?php echo get_option('bintray_debian'); ?>" >
	<input type="text" name="bintray_devportal" placeholder="Enter DevPortal Theme Bintray URL" value="<?php echo get_option('bintray_devportal'); ?>" >

<?php }

function display_licenseAPI_element(){ ?>

	<input type="text" name="licenseAPI_user" placeholder="User" value="<?php echo get_option('licenseAPI_user'); ?>" >
	<input type="text" name="licenseAPI_token" placeholder="Token" value="<?php echo get_option('licenseAPI_token'); ?>" >

<?php }


function display_clearbit_element(){ ?>

	<input type="text" name="clearbit_risk_apikey" placeholder="Enter Clearbit Risk API Key" value="<?php echo get_option('clearbit_risk_apikey'); ?>" >

<?php }

function display_salesforce_element(){ ?>

	<input type="text" name="salesforce_client_id" placeholder="Client ID" value="<?php echo get_option('salesforce_client_id'); ?>" >
	<input type="text" name="salesforce_client_secret" placeholder="Client Secret" value="<?php echo get_option('salesforce_client_secret'); ?>" >
	<input type="text" name="salesforce_username" placeholder="Username" value="<?php echo get_option('salesforce_username'); ?>" >
	<input type="text" name="salesforce_password" placeholder="User Pass" value="<?php echo get_option('salesforce_password'); ?>" >

<?php }


/**
 *
 * Here you tell WP what to enqueue into the <form> area. You need:
 *
 * 1. add_settings_section
 * 2. add_settings_field
 * 3. register_setting
 *
 */

function display_kong_version_fields(){

	add_settings_section("section", null, null, "kong-version-options");

	add_settings_field("kong_version", "Kong Version No.", "display_kong_version_element", "kong-version-options", "section");

	register_setting("section", "kong_version");
}

add_action("admin_init", "display_kong_version_fields");

// PARDOT

function display_pardot_user_fields(){

	add_settings_section("pardot-options", null, null, "pardot_options");

	add_settings_field("pardot_user_details", "Pardot User details", "display_pardot_element", "pardot_options", "pardot-options");

	register_setting("pardot-options", "pardot_email");
	register_setting("pardot-options", "pardot_pass");
	register_setting("pardot-options", "pardot_key");
}

add_action("admin_init", "display_pardot_user_fields");

// ZENDESK

function display_zendesk_user_fields() {

	add_settings_section("zendesk-options", null, null, "zendesk_options");

	add_settings_field("zendesk_user_details", "Zendesk User Email with access token", "display_zendesk_element", "zendesk_options", "zendesk-options");

	register_setting("zendesk-options", "zendesk_email");

}

add_action("admin_init", "display_zendesk_user_fields");

// BINTRAY

function display_bintray_user_fields() {

	add_settings_section("bintray-options", null, null, "bintray_options");

	add_settings_field("bintray_user_details", "Bintray Free Trials Information", "display_bintray_element", "bintray_options", "bintray-options");


	register_setting("bintray-options", "bintray_key");
	register_setting("bintray-options", "bintray_robot_key");
	register_setting("bintray-options", "bintray_docker");
	register_setting("bintray-options", "bintray_aws");
	register_setting("bintray-options", "bintray_centos");
	register_setting("bintray-options", "bintray_debian");
	register_setting("bintray-options", "bintray_devportal");

}

add_action("admin_init", "display_bintray_user_fields");

// LICENSE API

function display_licenseAPI_user_fields() {

	add_settings_section("licenseAPI-options", null, null, "licenseAPI_options");

	add_settings_field("licenseAPI_user_details", "License API User Info", "display_licenseAPI_element", "licenseAPI_options", "licenseAPI-options");


	register_setting("licenseAPI-options", "licenseAPI_user");
	register_setting("licenseAPI-options", "licenseAPI_token");

}

add_action("admin_init", "display_licenseAPI_user_fields");

// CLEARBIT
function display_clearbit_user_fields() {
	add_settings_section("clearbit-options", null, null, "clearbit_options");
	add_settings_field("clearbit_risk_apikey", "Clearbit API", "display_clearbit_element", "clearbit_options", "clearbit-options");
	register_setting("clearbit-options", "clearbit_risk_apikey");
}

add_action("admin_init", "display_clearbit_user_fields");

// Salesforce
function display_salesforce_user_fields() {
	add_settings_section("salesforce-options", null, null, "salesforce_options");

	add_settings_field("salesforce_user_details", "Salesforce", "display_salesforce_element", "salesforce_options", "salesforce-options");

	register_setting("salesforce-options", "salesforce_client_id");
	register_setting("salesforce-options", "salesforce_client_secret");
	register_setting("salesforce-options", "salesforce_username");
	register_setting("salesforce-options", "salesforce_password");
}

add_action("admin_init", "display_salesforce_user_fields");

/**
 *
 * Tie it all together by adding the settings page to wherever you like. For this example it will appear
 * in Settings > Contact Info
 *
 */

function add_custom_info_menu_item(){

	add_options_page("Kong Version", "Kong Version", "manage_options", "kong-version", "theme_settings_page");
	add_options_page("Pardot User", "Pardot User", "manage_options", "pardot-settings", "pardot_settings_page");

}

add_action("admin_menu", "add_custom_info_menu_item");
