'use strict';

var gulp = require('gulp')
var autoprefixer = require('gulp-autoprefixer')
var browserSync = require('browser-sync')
var cssmin = require('gulp-cssmin')
var concat = require('gulp-concat')
var sourcemaps = require('gulp-sourcemaps')
var sass = require('gulp-sass')
var uglify = require('gulp-uglify')
var wpRev = require('gulp-wp-rev')

// Concatenate and minify js
gulp.task('kongsummit:js', function () {
  return gulp.src('assets/js/kong-summit/*.js')
    .pipe(sourcemaps.init())
    .pipe(concat('kong-summit.min.js'))
    .pipe(uglify())
    .on('error', function (err) { gutil.log(gutil.colors.red('[Error]'), err.toString()); })
    .pipe(sourcemaps.write('maps'))
    .pipe(gulp.dest('assets/js'))
    .pipe(browserSync.reload({ stream: true }))
})

// Concatenate css
gulp.task('kongsummit:sass', function () {
  return gulp.src('sass/kong-summit/style.scss')
    .pipe(sourcemaps.init())
    .pipe(sass().on('error', sass.logError))
    .pipe(autoprefixer())
    .pipe(concat('kong-summit.min.css'))
    .pipe(cssmin())
    .pipe(sourcemaps.write('maps'))
    .pipe(gulp.dest('assets/css'))
    .pipe(browserSync.reload({ stream: true }))
})

gulp.task('kongsummit:version', function () {
  return gulp.src('./functions/enqueue-versioned-scripts.php')
    .pipe(wpRev({
      css: './assets/css/kong-summit.min.css',
      cssHandle: 'kongsummit_assets',
      js: './assets/js/kong-summit.min.js',
      jsHandle: 'kongsummit_assets'
    }))
    .pipe(gulp.dest('./functions'))
})

gulp.task('kongsummit:build', function () {
  gulp.start('kongsummit:sass')
  gulp.start('kongsummit:js')
  gulp.start('kongsummit:version')
})

// Run to concatenate css, build js, build bootstrap js and livereload
gulp.task('kongsummit', ['browserSync', 'kongsummit:sass', 'kongsummit:js'], function () {
  gulp.watch('sass/kong-summit/**/*.scss', ['kongsummit:sass'])
  gulp.watch('assets/js/kong-summit/*.js', ['kongsummit:js'])
  gulp.watch('**/*.php', ['files'])
})
