<?php
// Hook into WP to get DB values
require_once( $_SERVER['DOCUMENT_ROOT'] . '/wp-load.php' );

function createLicense($licenseKey, $company)
{
  // Build values for license command
  $license_host= "https://license.api.konghq.com/v1/licenses";
  // Build URL
  $licenseBintrayURL = 'https://api.bintray.com/signed_url/kong/kong-enterprise-free-trials-licenses/dists/license-' . $licenseKey . '.json';

  $date=strtotime("+1 Months");
  $expirationDate =  date("Y-m-d", $date);

  $service_token = get_option('licenseAPI_token');
  $service_user = get_option('licenseAPI_user');
  $product = "Kong Enterprise Edition";
  $support = "None";
  $adminSeats = "5";

  //generate license with HTTP POST
  $ch = curl_init();
  curl_setopt($ch, CURLOPT_URL, $license_host);
  curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
  curl_setopt($ch, CURLOPT_HTTPAUTH, CURLAUTH_BASIC);
  curl_setopt($ch, CURLOPT_USERPWD, "$service_user:$service_token");
  curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 'FALSE');
  curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 'FALSE');
  curl_setopt($ch, CURLOPT_POST, true);
  $datatopost = array(
      "customer" => "$company",
      "product_subscription" => "$product",
      "support_plan" => "$support",
      "admin_seats" => "$adminSeats",
      "license_expiration_date" => "$expirationDate",
      "license_key" => "$licenseKey",
  );

  curl_setopt($ch, CURLOPT_POSTFIELDS, $datatopost);
  $response = curl_exec($ch);
  $code = curl_getinfo($ch)['http_code'];
  curl_close($ch);

  if($code != 200) {
    logErrorToCSV("License Error Response Code: ", $code);
    logErrorToCSV("License Response: ", $response);
    throw new Exception("Failure: Could not create license");
  }

  return $response;
}

// Store License File in temp WP file
function saveLicenseFile($licenseKey, $licenseData) {
  $fileName = '/licenses/license-' . $licenseKey . '.json';

  $licenseFile = fopen($_SERVER['DOCUMENT_ROOT'] . "/wp-content/themes/konghq/inc" . $fileName, "w");
  if(!$licenseFile) {
    throw new Exception("Failure: Could not open new license file");
  }
  $putLicense = fputs($licenseFile, $licenseData);
  if(!$putLicense) {
    throw new Exception("Could not inject license data into license file");
  }

  fclose($licenseFile);

}

// Submit license file to Bintray
function publishLicenseToBintray($licenseKey) {
  $licenseRepoURL = 'https://api.bintray.com/content/kong/kong-enterprise-free-trials-licenses/licenses/1.0/dists/';
  $robotUserKey = get_option('bintray_robot_key');

  // Build License File information
  $licenseFileName = 'license-' . $licenseKey . '.json';
  $filePath = $_SERVER['DOCUMENT_ROOT'] . "/wp-content/themes/konghq/inc/licenses/" . $licenseFileName;

  if(!$filePath) {
    throw new Exception("Failure: License file cannot be found");
  }

  $fh = fopen($filePath, 'r');
  if(!$fh) {
    throw new Exception("Failure: License file could not be accessed");
  }

  $curl = curl_init();

  curl_setopt_array($curl, array(
    CURLOPT_URL => $licenseRepoURL . $licenseFileName . '?publish=1&override=1',
    CURLOPT_PUT => 1,
    CURLOPT_INFILE => $fh,
    CURLOPT_RETURNTRANSFER => true,
    CURLOPT_CONNECTTIMEOUT => 10,
    CURLOPT_HTTPHEADER => array(
      "authorization: Basic " . $robotUserKey,
      "cache-control: no-cache",
      "content-type: application/json",
    ),
  ));

  $response = curl_exec($curl);
  $code = curl_getinfo($curl)['http_code'];
  curl_close($curl);
  fclose($fh);

  if($code != 201) {
    logErrorToCSV("Bintray Response Code: ", $code);
    logErrorToCSV("Bintray Response: ", $response);
    throw new Exception("Failure: Could not publish license to bintray");
  }
  return $response;
}
