<?php
// Hook into WP to get DB values
require_once( $_SERVER['DOCUMENT_ROOT'] . '/wp-load.php' );

// Get Pardot user creds from WP Database
$userKey = get_option('pardot_key');
$userEmail = get_option('pardot_email');
$userPass = get_option('pardot_pass');

// Setup Constants
$campaignId = 54242; // Free Trial default campaign
$templateId = 33492; // Free Trial Welcome email template

// Get API Key from Pardot using a generic user credentials
function getPardotAuth() {
  // Get global variables
  global $userKey, $userEmail, $userPass;
  $curl = curl_init();
  curl_setopt_array($curl, array(
    CURLOPT_URL => "https://pi.pardot.com/api/login/version/4/?email=" . $userEmail . "&password=" . $userPass . "&user_key=" . $userKey,
    CURLOPT_TIMEOUT => 30,
    CURLOPT_CUSTOMREQUEST => "POST",
    CURLOPT_RETURNTRANSFER => true
  ));
  $response = curl_exec($curl);
  $err = curl_error($curl);
  
  if ($err) {
    throw new Exception('failure: pardot auth failed');
  }
  // Store XML response from Pardot
  $xml = new SimpleXMLElement($response);
  // Get request status value
  $status = (string) $xml['stat'];
  // Get API key if returned
  curl_close($curl);

  if ($status !== 'ok') {
    throw new Exception('failure: pardot auth failed');
  }

  return (string) $xml->api_key;
}

// Take email address provided and check if prospect already exists or not
function checkForExistingProspect($apiKey, $visitorEmail) {
  
  //Get Global Vars
  global $userKey;
  $curl = curl_init();
  curl_setopt_array($curl, array(
    CURLOPT_URL => "https://pi.pardot.com/api/prospect/version/4/do/read/email/" . $visitorEmail . "&api_key=" . $apiKey . "&user_key=" . $userKey, 
    CURLOPT_TIMEOUT => 30,
    CURLOPT_CUSTOMREQUEST => "POST",
    CURLOPT_RETURNTRANSFER => true,
  ));
  $response = curl_exec($curl);
  $err = curl_error($curl);
  
  if ($err) {
    throw new Exception('failure: error checking for existing prospect');
  }
  // Store XML response from Pardot
  $xml = new SimpleXMLElement($response);
  // Get request status value
  $status = (string) $xml['stat'];
  curl_close($curl);

  if ($status !== 'ok') {
    return false;
  }
  
  return (string) $xml->prospect->id;
}

// Update existing prospect
function updateExistingProspect($prospectId, $apiKey, $fields) {
  // Get global vars
  global $userKey;
  $curl = curl_init();
  curl_setopt_array($curl, array(
    CURLOPT_URL => "https://pi.pardot.com/api/prospect/version/4/do/update/id/" . $prospectId . "?" . $fields . "&api_key=" . $apiKey . "&user_key=" . $userKey,
    CURLOPT_TIMEOUT => 30,
    CURLOPT_CUSTOMREQUEST => "POST",
    CURLOPT_RETURNTRANSFER => true,
  ));
  $response = curl_exec($curl);
  $err = curl_error($curl);
  
  if ($err) {
    throw new Exception('failure: could not update user');
  }
  // Store XML response from Pardot
  $xml = new SimpleXMLElement($response);
  // Get request status value
  $status = (string) $xml['stat'];
  curl_close($curl);

  if ($status !== 'ok') {
    throw new Exception('failure: could not update user');
  }

  return $status;
}

// Create new prospect
function createNewProspect($apiKey, $fields) {
  global $userKey;
  // If fields starts with email= strip out it out. 
  // To create a new user in Pardot you cannot have `email=`
  // If left in it will be treated as part of the email address ('email=email@domain.com') <- not good
  $updateFields = preg_replace('/^email=/', '', $fields);
  $curl = curl_init();
  curl_setopt_array($curl, array(
    CURLOPT_URL => "https://pi.pardot.com/api/prospect/version/4/do/create/email/" . $updateFields . "&api_key=" . $apiKey . "&user_key=" . $userKey,
    CURLOPT_TIMEOUT => 30,
    CURLOPT_CUSTOMREQUEST => "POST",
    CURLOPT_RETURNTRANSFER => true,
  ));
  $response = curl_exec($curl);
  $err = curl_error($curl);
  
  if ($err) {
    throw new Exception('failure: could not create new user');
  }
  // Store XML response from Pardot
  $xml = new SimpleXMLElement($response);
  // Get request status value
  $status = (string) $xml['stat'];
  curl_close($curl);
  if ($status !== 'ok') {
    throw new Exception('failure: could not create new user');
  }
  
  return $status;
}
