<?php
// Hook into WP to get DB values
require_once( $_SERVER['DOCUMENT_ROOT'] . '/wp-load.php' );

class SalesforceClient {

  public function __construct() {
    $auth = $this->getAuth();
    $this->instanceUrl = $auth->instance_url;
    $this->token = $auth->access_token;
  }

  public function findOrCreateCustomerEngagement($recordId, $recordType) {
    $soql = "SELECT" . "+Id,+License_Key__c+FROM+Customer_Engagement__c+WHERE+Record_Lock__c+=+FALSE+AND+" . $recordType . "__c+=+'" . $recordId . "'";
    $record = $this->getRecord($soql);

    if (!$record) {
      $updateParamsTrue = [
        "Free_Trial_Form__c" => "true",
        "Eval_Click_Thru__c" => "true"
      ];
      $this->updateRecord($recordId, $recordType, $updateParamsTrue);
      $soql = "SELECT" . "+Id,+License_Key__c+FROM+Customer_Engagement__c+WHERE+Record_Lock__c+=+FALSE+AND+" . $recordType . "__c+=+'" . $recordId . "'";
      $record = $this->getRecord($soql);
    }
    //If record exists & Record Lock is false, return record to be sent to Bintray
    if ($record) {
      return $record;
    }

    //If record does not exist check whether Record Lock is set, and determine Exception
    $soql = "SELECT" . "+Id,+License_Key__c+FROM+Customer_Engagement__c+WHERE+Record_Lock__c+=+TRUE+AND+" . $recordType . "__c+=+'" . $recordId . "'";
    $record = $this->getRecord($soql);

    if ($record) {
      throw new Exception("Saleforce: Record Already Exists");
    } else {
      throw new Exception("Saleforce: Couldnt find Customer Engagement Record");
    }
  }

  public function findOrCreateUserRecord($email, $firstName, $lastName, $company) {
    //encode email to control for special chars in soql calls
    $emailEncoded = urlencode($email);
    $lastNameEncoded = urlencode($lastName);
    $soql = "SELECT" . "+Id+FROM+Contact+WHERE+Email+=+'" . $emailEncoded . "'+AND+LastName+=+'" . $lastNameEncoded . "'";
    $record = $this->getRecord($soql);

    if (!$record) {
      $soql = "SELECT" . "+Id+FROM+Lead+WHERE+Email+=+'" . $emailEncoded . "'+AND+LastName+=+'" . $lastNameEncoded . "'";
      $record = $this->getRecord($soql);
    }
    if (!$record) {
      $params = [
        "Email" => $email,
        "LastName" => $lastName,
        "FirstName" => $firstName,
        "Company" => $company,
        "RecordTypeId" => "01241000000jdTMAAY",
        "LeadSource" => "Web",
        "Lead_Source_Detail__c" => "Free-trial",
        "Free_Trial_Form__c" => "true",
        "Eval_Click_Thru__c" => "true"
      ];
      $record = $this->createRecord($params, "Lead");
      $record = $this->getRecord($soql);
    }

    if (!$record) {
      throw new Exception("Saleforce: Couldnt find User Record");
    }
    return $record;
  }

  public function updateRecord($recordId, $recordType, $params) {
    $token_url = $this->instanceUrl . "/services/data/v42.0/sobjects/" . $recordType . "/" . $recordId;
    $header = array(
      "Authorization: Bearer " . $this->token,
      "Content-Type: application/json",
      "Accept: application/json"
    );

    $curl = curl_init($token_url);
    curl_setopt($curl, CURLOPT_HTTPHEADER, $header);
    curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($curl, CURLOPT_CUSTOMREQUEST, 'PATCH');
    curl_setopt($curl, CURLOPT_POSTFIELDS, json_encode($params));

    $json_response = curl_exec($curl);
    curl_close($curl);
    return json_decode($json_response);
  }

  private function getAuth() {
    $token_url = "https://login.salesforce.com/services/oauth2/token";
    $params = "grant_type=password"
        . "&client_id=" . get_option('salesforce_client_id')
        . "&client_secret=" . get_option('salesforce_client_secret')
        . "&username=" . get_option('salesforce_username')
        . "&password=" . get_option('salesforce_password');

    $curl = curl_init($token_url);
    curl_setopt($curl, CURLOPT_HEADER, false);
    curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($curl, CURLOPT_POST, true);
    curl_setopt($curl, CURLOPT_POSTFIELDS, $params);

    $json_response = curl_exec($curl);
    $code = curl_getinfo($curl)['http_code'];
    curl_close($curl);

    if($code != 200) {
      logErrorToCSV("Salesforce Auth Response Code: ", $code);
      logErrorToCSV("Salesforce Auth Response: ", $json_response);
      throw new Exception("Failure: Could not authorize Salesforce");
    }

    return json_decode($json_response);
  }

  private function getRecord($soql) {
    $token_url = $this->instanceUrl . "/services/data/v42.0/query/?q=" . $soql;
    $header = array(
      "Authorization: Bearer " . $this->token,
      "Content-Type: application/json",
      "Accept: application/json"
    );

    $curl = curl_init($token_url);
    curl_setopt($curl, CURLOPT_HTTPHEADER, $header);
    curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);

    $json_response = curl_exec($curl);
    $code = curl_getinfo($curl)['http_code'];
    curl_close($curl);

    if($code != 200 && code != 201) {
      logErrorToCSV("Salesforce Get Record Response Code: ", $code);
      logErrorToCSV("Salesforce Get Record Response: ", $json_response);
      throw new Exception("Failure: Could not retrieve record from Salesforce");
    }
    return json_decode($json_response)->records;
  }

  private function createRecord($params, $recordType) {
    $token_url = $this->instanceUrl . "/services/data/v42.0/sobjects/" . $recordType . "/";
    $header = array(
      "Authorization: Bearer " . $this->token,
      "Content-Type: application/json",
      "Accept: application/json"
    );

    $curl = curl_init($token_url);
    curl_setopt($curl, CURLOPT_HTTPHEADER, $header);
    curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($curl, CURLOPT_POST, true);
    curl_setopt($curl, CURLOPT_POSTFIELDS, json_encode($params));

    $json_response = curl_exec($curl);
    $code = curl_getinfo($curl)['http_code'];
    curl_close($curl);

    if($code != 200 && $code != 201) {
      logErrorToCSV("Salesforce Create Record Code: ", $code);
      logErrorToCSV("Salesforce Create Record Response: ", $json_response);
      throw new Exception("Failure: Could not create record in Salesforce");
    }
    return json_decode($json_response);
  }
}
