<?php

class ZendeskClient
{
  const API_URL = 'https://mashape.zendesk.com/api/v2/users/create_or_update.json/';

  public function createZendeskUser($visitorFullName, $visitorEmail)
  {
    $userToken = get_option('zendesk_email');
    $curl = curl_init();

    $params = array(
      'user' => array(
        'name' => $visitorFullName,
        'email' => $visitorEmail,
        'user_fields' => [
          'trial_start_date' => date('c') // ISO 8601 date, e.g. 2004-02-12T15:19:21+00:00
        ],
        'verified' => 'true'
      )
    );
    $params_string = json_encode($params);
    curl_setopt_array($curl, array(
      CURLOPT_URL => self::API_URL,
      CURLOPT_USERPWD => $userToken,
      CURLOPT_POSTFIELDS => $params_string,
      CURLOPT_RETURNTRANSFER => true,
      CURLOPT_HTTPHEADER => array(
        'Content-Type: application/json',
        'Content-Length: ' . strlen($params_string),
      ),
    ));
    $response = curl_exec($curl);
    $code = curl_getinfo($curl)['http_code'];
    curl_close($curl);
  
    if(!in_array($code, [201, 200])) {
      logErrorToCSV("Zendesk Error Response Code: ", $code);
      logErrorToCSV("Zendesk Response: ", $response);
      throw new Exception("Failure: could not create Zendesk account");
    }
    
    if(!isset(json_decode($response)->user)) {
      logErrorToCSV("Zendesk Error Response Code: ", $code);
      logErrorToCSV("Zendesk Response: ", $response);
      throw new Exception("Failure: could not verify Zendesk account was created, 'user' not in curl response");
    }

    return json_decode($response)->user->id;
  }

  public function updateUser($id) {
    $userToken = get_option('zendesk_email');
    $curl = curl_init();

    $params = array(
      'tags' => '[free_trial_user]',
  
    );
    $params_string = json_encode($params);
    curl_setopt_array($curl, array(
      CURLOPT_URL => 'https://mashape.zendesk.com/api/v2/users/' . $id . '/tags.json',
      CURLOPT_USERPWD => $userToken,
      CURLOPT_POSTFIELDS => $params_string,
      CURLOPT_RETURNTRANSFER => true,
      CURLOPT_CUSTOMREQUEST => "PUT",
      CURLOPT_HTTPHEADER => array(
        'Content-Type: application/json',
      ),
    ));
    $response = curl_exec($curl);
    $code = curl_getinfo($curl)['http_code'];
    curl_close($curl);
  
    if(!in_array($code, [201, 200])) {
      logErrorToCSV("Zendesk Error Response Code: ", $code);
      logErrorToCSV("Zendesk Response: ", $response);
      throw new Exception("Failure: could not update Zendesk account");
    }
    return json_decode($response);
  }
}
