var gulp = require('gulp')
var gutil = require('gulp-util')
var sass = require('gulp-sass')
var sourcemaps = require('gulp-sourcemaps')
var cssmin = require('gulp-cssmin')
var uglify = require('gulp-uglify')
var concat = require('gulp-concat')
var uncss = require('gulp-uncss')
var shell = require('gulp-shell')
var autoprefixer = require('gulp-autoprefixer')
var browserSync = require('browser-sync')
var wpRev = require('gulp-wp-rev')

require('./gulp/tasks/kongsummit.js');

// Run browsersync on dev start
gulp.task('browserSync', function () {
  browserSync({
    proxy: 'konghq.dev',
    options: {
      reloadDelay: 250
    },
    notify: {
      styles: {
        top: 'auto',
        bottom: '0',
        margin: '0px',
        padding: '5px',
        position: 'fixed',
        fontSize: '10px',
        zIndex: '9999',
        borderRadius: '5px 0px 0px',
        color: 'white',
        textAlign: 'center',
        display: 'block',
        backgroundColor: 'rgba(60, 197, 31, 0.498039)'
      }
    }
  })
})

// Watch files for changes
gulp.task('files', function () {
  // Watch any and all HTML files and refresh when something changes
  return gulp.src('**/*.php')
    .pipe(browserSync.reload({ stream: true }))
})

// Concatenate and minify js
gulp.task('js', function () {
  return gulp.src('assets/js/scripts/*.js')
    .pipe(sourcemaps.init())
    .pipe(concat('site.min.js'))
    .pipe(uglify())
    .on('error', function (err) { gutil.log(gutil.colors.red('[Error]'), err.toString()); })
    .pipe(sourcemaps.write('maps'))
    .pipe(gulp.dest('assets/js'))
    .pipe(browserSync.reload({ stream: true }))
})

// Concatenate and minify needed Bootstap js
gulp.task('bootstrap', function () {
  return gulp.src([
    'node_modules/bootstrap/js/dist/util.js',
    'node_modules/bootstrap/js/dist/carousel.js',
    'node_modules/bootstrap/js/dist/modal.js',
    'node_modules/bootstrap/js/dist/scrollspy.js',
  ])
    .pipe(sourcemaps.init())
    .pipe(concat('bootstrap.min.js'))
    .pipe(uglify())
    .pipe(sourcemaps.write('maps'))
    .pipe(gulp.dest('assets/js/vendor'))
})

// Concatenate and minify needed jQuery js
gulp.task('jquery', function () {
  return gulp.src([
    'node_modules/jquery/dist/jquery.min.js',
    'node_modules/jquery.cookie/jquery.cookie.js'
  ])
    .pipe(sourcemaps.init())
    .pipe(concat('jquery.min.js'))
    .pipe(uglify())
    .pipe(sourcemaps.write('maps'))
    .pipe(gulp.dest('assets/js/vendor'))
})

// Concatenate css
gulp.task('sass', function () {
  return gulp.src('sass/style.scss')
    .pipe(sourcemaps.init())
    .pipe(sass().on('error', sass.logError))
    .pipe(autoprefixer())
    .pipe(concat('styles.min.css'))
    .pipe(cssmin())
    .pipe(sourcemaps.write('maps'))
    .pipe(gulp.dest('assets/css'))
    .pipe(browserSync.reload({ stream: true }))
})

gulp.task('version', function () {
  return gulp.src('./functions/enqueue-versioned-scripts.php')
    .pipe(wpRev({
      css: './assets/css/styles.min.css',
      cssHandle: 'assets',
      js: './assets/js/site.min.js',
      jsHandle: 'assets'
    }))
    .pipe(gulp.dest('./functions'))
})

// Generate Sitemap JSON for uncss
gulp.task('sitemap', shell.task(['curl --silent --output sitemap.json http://konghq.dev/?show_sitemap']));

// UnCSS and minify css
gulp.task('uncss', function () {
  return gulp.src('assets/css/styles.min.css')
    .pipe(uncss({
      html: JSON.parse(require('fs').readFileSync('sitemap.json', 'utf-8')),
      ignore: [
        /\.kong-navbar-collapse--expand/,
        /\.btn-*/,
        /\.has-danger/,
        /\.animate/,
        /\.active/,
        /\.offset-1/,
        /\.related-posts header + .kong-article/,
        /\.enterprise/,
        /\.open-source/,
        /\.plugin-card/,
        /\.error/,
        /\.btn-highlight/,
        /\#wpadminbar/,
        /\.admin-bar/,
        /\.modal-open/,
        /\.modal-backdrop/,
        /\.show/,
        /\.fade/,
        /\.carousel-item-right/,
        /\.carousel-item-left/,
        /\.carousel-item-next/,
        /\.carousel-item-prev/,
        /\.hljs-string/,
        /\.hljs-regexp/,
        /\.hljs-addition/,
        /\.hljs-attribute/,
        /\.hljs-meta-string/,
        /\.has-img/,
        /\.cat-news/,
        /\.cat-community/,
        /\.cat-enterprise/,
        /\.cat-how-to/,
        /\.cat-events/,
        /\.cat-product-announcements/,
        /\.fa-facebook-offical/,
        /\.fa-twitter/,
        /\.fa-meetup/,
        /\.fa-github/,
        /\.no-decoration/,
        /\.can-scroll/,
        /\.sticky/
      ]
    }))
    .pipe(cssmin())
    .pipe(gulp.dest('assets/css'))
})

gulp.task('build', function () {
  gulp.start('sass')
  gulp.start('js')
  gulp.start('version')
})

// Run to concatenate css, build js, build bootstrap js and livereload
gulp.task('default', ['browserSync', 'sass', 'js', 'bootstrap', 'jquery'], function () {
  // List of watchers, so it will watch all of the following files waiting for changes
  gulp.watch('sass/**/*.scss', ['sass'])
  gulp.watch('assets/js/scripts/*.js', ['js'])
  gulp.watch('**/*.php', ['files'])
})
