<?php
// Hook into WP to get DB values
require_once( $_SERVER['DOCUMENT_ROOT'] . '/wp-load.php' );

// GET SignedURLS from Bintray
function getSignedURL($url, $licenseKey) {

  $userKey = get_option('bintray_key');
  $curl = curl_init();

  $params = array(
    'valid_for_secs' => '2592000',
    'callback_id' => $licenseKey
  );

  $params_string = json_encode($params);
  curl_setopt_array($curl, array(
    CURLOPT_URL => $url,
    CURLOPT_POSTFIELDS => $params_string,
    CURLOPT_RETURNTRANSFER => true,
    CURLOPT_CUSTOMREQUEST => "POST",
    CURLOPT_CONNECTTIMEOUT => 10,
    CURLOPT_TIMEOUT => 10,
    CURLOPT_HTTPHEADER => array(
      "authorization: Basic " . $userKey,
      "cache-control: no-cache",
      "content-type: application/json",
    ),
  ));
  
  $response = curl_exec($curl);
  $code = curl_getinfo($curl)['http_code'];
  curl_close($curl);
  
  if($code != 200) {
    logErrorToCSV("Bintray Error Response Code: ", $code);
    logErrorToCSV("Bintray Response: ", $response);
    throw new Exception("Failure: Could not retrieve signed url from Bintray " . $url);
  }
 
  $responseURL = json_decode($response, true);
  // secondary check
  if(!isset($responseURL['url'])) {
    logErrorToCSV("Bintray Error Response Code: ", $code);
    logErrorToCSV("Bintray Response: ", $response);
    throw new Exception("Failure: Could not retrieve signed url from Bintray");
  }
  return $responseURL['url'];
}

function getBintrayURLs($licenseKey) {
  $licenseURL = 'https://api.bintray.com/signed_url/kong/kong-enterprise-free-trials-licenses/dists/license-' . $licenseKey . '.json';
  $dockerURL = get_option('bintray_docker');
  $AWS = get_option('bintray_aws');
  $centOS = get_option('bintray_centos');
  $debian = get_option('bintray_debian');
  $devPortal = get_option('bintray_devportal');

  $licenseSigned = getSignedURL($licenseURL, $licenseKey);
  $dockerSigned = getSignedURL($dockerURL, $licenseKey);
  $AWSSigned = getSignedURL($AWS, $licenseKey);
  $centOSSigned = getSignedURL($centOS, $licenseKey);
  $debianSigned = getSignedURL($debian, $licenseKey);
  $devPortalSigned = getSignedURL($devPortal, $licenseKey);

  $bintrayURLS = array(
    'Bintray_License_URL__c' => $licenseSigned,
    'Bintray_Docker_URL__c' => $dockerSigned,
    'Bintray_CentOS_URL__c' => $centOSSigned,
    'Bintray_AWS_URL__c' => $AWSSigned,
    'Bintray_Debian_URL__c' => $debianSigned,
    'Bintray_DevPortal_URL__c' => $devPortalSigned
  );

  return $bintrayURLS;
}
