<?php

class ClearbitClient
{

  const API_URL = 'https://risk.clearbit.com/v1/calculate';

  private $apiKey;

  public function __construct($apiKey)
  {
    $this->apiKey = $apiKey;
  }

  public function calculateRisk($email, $name, $ip)
  {
    $curl = curl_init();

    $params = [
      "email" => $email,
      "name" => $name,
      "ip" => $ip
    ];

    try {
      $this->validateParams($params);
    } catch (Exception $e) {
      return $e->getMessage();
    }

    $params_string = json_encode($params);

    curl_setopt_array($curl, [
      CURLOPT_URL => self::API_URL,
      CURLOPT_RETURNTRANSFER => true,
      CURLOPT_ENCODING => "",
      CURLOPT_MAXREDIRS => 10,
      CURLOPT_USERPWD => $this->apiKey . ":",
      CURLOPT_TIMEOUT => 30,
      CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,
      CURLOPT_CUSTOMREQUEST => "POST",
      CURLOPT_RETURNTRANSFER => true,
      CURLOPT_POSTFIELDS => $params_string,
      CURLOPT_HTTPHEADER => array(
        "Accept: application/json",
        "Content-type: application/json",
        "Content-Length: " . strlen($params_string),
      ),
    ]);

    $response = curl_exec($curl);
    $err = curl_error($curl);

    curl_close($curl);

    if ($err || isset($response['error'])) {
      echo "cURL Error #:" . $err;
    } else {
      return json_decode($response);
    }
  }

  public function isSafe($riskResponse)
  {
    if ($riskResponse->error) {
      return false;
    }

    if ($riskResponse->email
      && $riskResponse->email->valid
      && $riskResponse->risk
      && $riskResponse->risk->level !== 'high') {
      return true;
    }

    return false;
  }

  /**
   * Validate params and throw first error.
   */
  private function validateParams($params)
  {
    if (!filter_var($params['email'], FILTER_VALIDATE_EMAIL)) {
      logErrorToCSV("Email is invalid: ", $params['email']);
      throw new Exception("Email is invalid.");
    }

    if (!filter_var($params['ip'], FILTER_VALIDATE_IP)) {
      logErrorToCSV("Invalid IP: ", $params['ip']);
      throw new Exception("Invalid IP address.");
    }
  }
}
