<?php
// Hook into WP to get DB values
require_once($_SERVER['DOCUMENT_ROOT'] . '/wp-load.php');
require_once('salesforce.php');
require_once('license.php');
require_once('bintray.php');
require_once('zendesk.php');
require_once('error-helper.php');
require_once('validate-emails.php');
header("Content-Type: application/json");

/*
  WORKFLOW
  0. Get form fields
  1. Find or create lead in Salesforce
  2. Salesforce creates the customer engagement and returns the license key
  3. Call license api to generate license
  4. Save license data to file under inc/licenses
  5. Publish file to Bintray
  6. Create all signed urls from Bintray
  7. Update Customer Engagement in Salesforce with Bintray URLs
  8. Create user in Zendesk
*/

// FORM FIELDS
$visitorEmail = $_POST['email'];

$emailValidationResponse = validateEmail($visitorEmail);

if($emailValidationResponse['status'] == 'invalid'){
  $response = [
    "status" => $emailValidationResponse['status'],
    "type" => $emailValidationResponse['type']
  ];
  echo json_encode($response);
  return;
}

$visitorFirstName = filter_var($_POST['first_name'], FILTER_SANITIZE_STRING);
$visitorLastName = filter_var($_POST['last_name'], FILTER_SANITIZE_STRING);
$visitorCompany = filter_var($_POST['company'], FILTER_SANITIZE_STRING);
// Combine First and Last name for Zendesk submission
$visitorFullName = $visitorFirstName . " " . $visitorLastName;


function registerFreeTrialUser() {
  global $visitorEmail, $visitorFirstName, $visitorLastName, $visitorFullName, $visitorCompany;
  try {
    $salesforce = new SalesforceClient();

    //Get or create user record (Contact or Lead) and grab record id & record type.
    $userRecord = $salesforce->findOrCreateUserRecord($visitorEmail, $visitorFirstName, $visitorLastName, $visitorCompany)[0];
    if(empty($userRecord)) {
      throw new Exception("Failure: no record found");
    }
    $userRecordId = $userRecord->Id ? $userRecord->Id : $userRecord->id;
    $userRecordType = $userRecord->attributes->type ? $userRecord->attributes->type : "Lead";

    //Get or create engagement record, and grab license key.
    $engagementRecord = $salesforce->findOrCreateCustomerEngagement($userRecordId, $userRecordType)[0];
    $licenseKey = $engagementRecord->License_Key__c;
    $engagementRecordId = $engagementRecord->Id;

    $licenseData = createLicense($licenseKey, $visitorCompany);
    saveLicenseFile($licenseKey, $licenseData);
    publishLicenseToBintray($licenseKey);
    $bintrayURLs = getBintrayURLs($licenseKey);
    $salesforce->updateRecord($engagementRecordId, "Customer_Engagement__c", $bintrayURLs);
    $zendesk = new ZendeskClient();
    $zendeskId = $zendesk->createZendeskUser($visitorFullName, $visitorEmail);
    $zendesk->updateUser($zendeskId);

    $newRelicData = array(
      "license_key"=> $licenseKey,
      "user_record_id"=> $userRecordId,
      "user_record_type"=> $userRecordType
    );
    $response = [
      "status" => "valid"
    ];

  } catch (Exception $e) {
    $_POST['email'] = $visitorEmail;
    logErrorToCSV('Failure: registerFreeTrialUser()', $e, $_POST);
    //logErrorToNewRelic('Failure: registerFreeTrialUser()', $e->getMessage(), $_POST);
    $response = [
      "status" => "invalid"
    ];
  }
  echo json_encode($response);
}

registerFreeTrialUser();
